@@ -10,9 +10,11 @@ from robot.utils.importer import Importer
 TRANSFORMERS = frozenset((
     'AssignmentNormalizer',
     'DiscardEmptySections',
+    'NormalizeNewLines',
     'NormalizeSectionHeaderName',
     'NormalizeSettingName',
-    'ReplaceRunKeywordIf'
+    'ReplaceRunKeywordIf',
+    'SplitTooLongLine'
 ))
 
 
